CallVerificationController class

Управляет сценарием «звонок с кодом» (SMS.RU code/call).

Inheritance

Constructors

CallVerificationController({SmsRuClient? client, CallSendDelegate? sendDelegate, CallVerificationMode mode = CallVerificationMode.send, Duration maxWaitDuration = const Duration(minutes: 5), void onVerified(String requestId, String enteredCode)?})

Properties

canEnterCode bool
no setter
code String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isBusy bool
no setter
lastError Object?
getter/setter pair
maxWaitDuration Duration
final
mode CallVerificationMode
final
onVerified → void Function(String requestId, String enteredCode)?
final
phone String?
getter/setter pair
requestId String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state CallVerificationState
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset() → void
startVerification(String phoneNumber) Future<void>
toString() String
A string representation of this object.
inherited
verifyCode(String enteredCode) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited